%if 0%{?fedora} || 0%{?rhel} == 6
%global with_devel 1
# package depends on kubernetes which atm does
# not provide complete source codes
%global with_bundled 1
# ELFRESERVE too small: 3104 > 3072
%global with_debug 0
# missing deps on kubernetes
%global with_check 0
%global with_unit_test 1
%else
%global with_devel 0
%global with_bundled 1
%global with_debug 0
%global with_check 0
%global with_unit_test 0
%endif

%if 0%{?with_debug}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif

%define copying() \
%if 0%{?fedora} >= 21 || 0%{?rhel} >= 7 \
%license %{*} \
%else \
%doc %{*} \
%endif

%global provider        github
%global provider_tld    com
%global project         appc
%global repo            spec
# https://github.com/appc/spec
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}
%global commit          37bef679148751952f169298fa0ea8171373d95c
%global shortcommit     %(c=%{commit}; echo ${c:0:7})

Name:           golang-%{provider}-%{project}-%{repo}
Version:        0.5.1
Release:        4.git%{shortcommit}%{?dist}
Summary:        Schema defs and tools for app container specification
License:        ASL 2.0
URL:            https://%{provider_prefix}
Source0:        https://%{provider_prefix}/archive/%{commit}/%{repo}-%{shortcommit}.tar.gz

# If go_arches not defined fall through to implicit golang archs
%if 0%{?go_arches:1}
ExclusiveArch:  %{go_arches}
%else
ExclusiveArch:   %{ix86} x86_64 %{arm}
%endif
# If gccgo_arches does not fit or is not defined fall through to golang
%ifarch 0%{?gccgo_arches}
BuildRequires:   gcc-go >= %{gccgo_min_vers}
%else
BuildRequires:   golang
%endif

Provides:   actool = %{version}-%{release}
Provides:   ace-validator = %{version}-%{release}

%description
%{summary}

%if 0%{?with_devel}
%package devel
Summary:       %{summary}
BuildArch:     noarch

%if 0%{?with_check}
#BuildRequires: golang(github.com/GoogleCloudPlatform/kubernetes/pkg/api/resource)
BuildRequires: golang(github.com/coreos/go-semver/semver) >= 0-0.2
BuildRequires: golang(golang.org/x/net/html)
BuildRequires: golang(golang.org/x/net/html/atom)
%endif

#Requires: golang(github.com/GoogleCloudPlatform/kubernetes/pkg/api/resource)
Requires: golang(github.com/coreos/go-semver/semver) >= 0-0.2
Requires: golang(golang.org/x/net/html)
Requires: golang(golang.org/x/net/html/atom)

Provides:      golang(%{import_path}/aci) = %{version}-%{release}
Provides:      golang(%{import_path}/discovery) = %{version}-%{release}
Provides:      golang(%{import_path}/pkg/acirenderer) = %{version}-%{release}
Provides:      golang(%{import_path}/pkg/tarheader) = %{version}-%{release}
Provides:      golang(%{import_path}/schema) = %{version}-%{release}
Provides:      golang(%{import_path}/schema/types) = %{version}-%{release}

%description devel
%{summary}

This package contains library source intended for
building other packages which use import path with
%{import_path} prefix.
%endif

%if 0%{?with_unit_test}
%package unit-test
Summary:         Unit tests for %{name} package
# If go_arches not defined fall through to implicit golang archs
%if 0%{?go_arches:1}
ExclusiveArch:  %{go_arches}
%else
ExclusiveArch:   %{ix86} x86_64 %{arm}
%endif
# If gccgo_arches does not fit or is not defined fall through to golang
%ifarch 0%{?gccgo_arches}
BuildRequires:   gcc-go >= %{gccgo_min_vers}
%else
BuildRequires:   golang
%endif

%if 0%{?with_check}
#Here comes all BuildRequires: PACKAGE the unit tests
#in %%check section need for running
%endif

# test subpackage tests code from devel subpackage
Requires:        %{name}-devel = %{version}-%{release}

%description unit-test
%{summary}

This package contains unit tests for project
providing packages with %{import_path} prefix.
%endif

%prep
%setup -q -n %{repo}-%{commit}

%build
mkdir -p src/github.com/appc
ln -s ../../../ src/github.com/appc/spec

%if 0%{?with_bundled}
export GOPATH=$(pwd):$(pwd)/Godeps/_workspace:%{gopath}
%else
export GOPATH=$(pwd):%{gopath}
%endif

%if 0%{?with_debug}
function gobuild { go build -a -ldflags "-B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \n')" -v -x "$@"; }
%else
function gobuild { go build -a "$@"; }
%endif

gobuild -o bin/actool %{import_path}/actool
gobuild -o bin/ace-validator -installsuffix ace %{import_path}/ace

find . -name "*.go" \
    -print |\
    xargs sed -i 's/github.com\/appc\/spec\/Godeps\/_workspace\/src\///g'

%install
install -d -p %{buildroot}%{_bindir}
install -p -m 755 bin/actool %{buildroot}%{_bindir}
install -p -m 755 bin/ace-validator %{buildroot}%{_bindir}

# source codes for building projects
%if 0%{?with_devel}
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/
# find all *.go but no *_test.go files and generate devel.file-list
for file in $(find . -iname "*.go" \! -iname "*_test.go" | grep -v "^./Godeps") ; do
    install -d -p %{buildroot}/%{gopath}/src/%{import_path}/$(dirname $file)
    cp -pav $file %{buildroot}/%{gopath}/src/%{import_path}/$file
    echo "%%{gopath}/src/%%{import_path}/$file" >> devel.file-list
done
%endif

# testing files for this project
%if 0%{?with_unit_test}
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/discovery
cp -pav discovery/myapp.html %{buildroot}/%{gopath}/src/%{import_path}/discovery/.
cp -pav discovery/myapp2.html %{buildroot}/%{gopath}/src/%{import_path}/discovery/.
echo "%%{gopath}/src/%%{import_path}/discovery/myapp.html" >> unit-test.file-list
echo "%%{gopath}/src/%%{import_path}/discovery/myapp2.html" >> unit-test.file-list
# find all *_test.go files and generate unit-test.file-list
for file in $(find . -iname "*_test.go" | grep -v "^./Godeps"); do
    install -d -p %{buildroot}/%{gopath}/src/%{import_path}/$(dirname $file)
    cp -pav $file %{buildroot}/%{gopath}/src/%{import_path}/$file
    echo "%%{gopath}/src/%%{import_path}/$file" >> unit-test.file-list
done
%endif

%check
%if 0%{?with_check} && 0%{?with_unit_test} && 0%{?with_devel}
%ifarch 0%{?gccgo_arches}
function gotest { %{gcc_go_test} "$@"; }
%else
%if 0%{?golang_test:1}
function gotest { %{golang_test} "$@"; }
%else
function gotest { go test "$@"; }
%endif
%endif

export GOPATH=%{buildroot}/%{gopath}:%{gopath}
gotest %{import_path}/aci
gotest %{import_path}/discovery
gotest %{import_path}/pkg/acirenderer
gotest %{import_path}/pkg/tarheader
gotest %{import_path}/schema
gotest %{import_path}/schema/types
%endif

%files
%copying LICENSE
%doc SPEC.md README.md OS-SPEC.md GUIDE.md CONTRIBUTING.md
%{_bindir}/actool
%{_bindir}/ace-validator

%if 0%{?with_devel}
%files devel -f devel.file-list
%copying LICENSE
%doc SPEC.md README.md OS-SPEC.md GUIDE.md CONTRIBUTING.md
%dir %{gopath}/src/%{provider}.%{provider_tld}/%{project}
%dir %{gopath}/src/%{import_path}
%endif

%if 0%{?with_unit_test}
%files unit-test -f unit-test.file-list
%copying LICENSE
%doc SPEC.md README.md OS-SPEC.md GUIDE.md CONTRIBUTING.md
%endif

%changelog
* Thu Jul 30 2015 jchaloup <jchaloup@redhat.com> - 0.5.1-4.git37bef67
- Update of spec file to spec-2.0
  resolves: #1248491

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.1-3.git37bef67
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Apr 02 2015 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0.5.1-2.git37bef67
- update to latest upstream master

* Fri Mar 27 2015 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0.5.1-1.gitc8559a2
- update to latest upstream master branch

* Wed Feb 18 2015 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0.3.0-2.gitfa6d3af
- only build for x86_64, ace-validator doesn't work for arm

* Wed Feb 18 2015 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0.3.0-1.gitfa6d3af
- update to commit fa6d3af86db496053a2d3c907c676fd9ee1118a8

* Tue Feb 03 2015 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0.2.0-2.git2fee340
- update to master commit#2fee340
- provide actool and ace-validator in main package
- remove mentions of fedora 19 (EOL)

* Sat Jan 31 2015 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0.2.0-1.git202fd7b
- Resolves: rhbz#1174030 - first package upload
- update to master commit#202fd7b

* Mon Dec 15 2014 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0.1.1-2
- update metaprovides
- update docs packaged

* Tue Dec 09 2014 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0.1.1-1
- First package for Fedora
